# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Fonts
ADDRESS_MONOSPACE_FONT_NAME = "Courier"

# icon paths
ICON_ACCOUNT_NO_WALLET = ":/images/locked_no_wallet"
ICON_ACCOUNT_WALLET_LOCKED = ":/images/locked"
ICON_ACCOUNT_WALLET_UNLOCKED = ":/images/unlocked"
ICON_NETWORK_CONNECTED = ":/icons/connected"
ICON_NETWORK_DISCONNECTED = ":/icons/disconnected"
ICON_IDENTITY = ":/icons/member_icon"
ICON_LOADER = ":/icons/loader"

# no activity delay before executing function when typing in ms
DEBOUNCE_TIME = 300
